@@ -858,8 +858,7 @@ draw_color_area (MateBG       *bg,
 
 static void
 draw_color (MateBG    *bg,
-	    GdkPixbuf *dest,
-	    GdkScreen *screen)
+	    GdkPixbuf *dest)
 {
 	GdkRectangle rect;
 
@@ -1025,7 +1024,6 @@ draw_image_for_thumb (MateBG     *bg,
 static void
 draw_once (MateBG    *bg,
 	   GdkPixbuf *dest,
-	   GdkScreen *screen,
 	   gboolean   is_root)
 {
 	GdkRectangle rect;
@@ -1086,9 +1084,9 @@ mate_bg_draw (MateBG     *bg,
 			draw_each_monitor (bg, dest, screen);
 		}
 	} else {
-		draw_color (bg, dest, screen);
+		draw_color (bg, dest);
 		if (bg->filename) {
-			draw_once (bg, dest, screen, is_root);
+			draw_once (bg, dest, is_root);
 		}
 	}
 }
@@ -1151,7 +1149,7 @@ mate_bg_get_pixmap_size (MateBG   *bg,
  * @window:
  * @width:
  * @height:
- * @is_root:
+ * @root:
  *
  * Create a surface that can be set as background for @window. If @is_root is
  * TRUE, the surface created will be created by a temporary X server connection
@@ -1168,7 +1166,7 @@ mate_bg_create_pixmap  (MateBG      *bg,
 		 	GdkWindow   *window,
 			int	     width,
 			int	     height,
-			gboolean     is_root)
+			gboolean     root)
 {
 	int pm_width, pm_height;
 
@@ -1189,7 +1187,7 @@ mate_bg_create_pixmap  (MateBG      *bg,
 	mate_bg_get_pixmap_size (bg, width, height, &pm_width, &pm_height);
 
 
-	if (is_root)
+	if (root)
 	{
 		surface = make_root_pixmap (window, pm_width, pm_height);
 	}
@@ -1213,7 +1211,7 @@ mate_bg_create_pixmap  (MateBG      *bg,
 
 		pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8,
 					 width, height);
-		mate_bg_draw (bg, pixbuf, gdk_window_get_screen (window), is_root);
+		mate_bg_draw (bg, pixbuf, gdk_window_get_screen (window), root);
 		gdk_cairo_set_source_pixbuf (cr, pixbuf, 0, 0);
 		g_object_unref (pixbuf);
 	}
@@ -1394,6 +1392,11 @@ fit_factor (int from_width, int from_height,
 	return MIN (to_width  / (double) from_width, to_height / (double) from_height);
 }
 
+/**
+ * mate_bg_create_thumbnail:
+ *
+ * Returns: (transfer full): a #GdkPixbuf showing the background as a thumbnail
+ */
 GdkPixbuf *
 mate_bg_create_thumbnail (MateBG               *bg,
 		           MateDesktopThumbnailFactory *factory,
@@ -1408,7 +1411,7 @@ mate_bg_create_thumbnail (MateBG               *bg,
 
 	result = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, dest_width, dest_height);
 
-	draw_color (bg, result, screen);
+	draw_color (bg, result);
 
 	if (bg->filename) {
 		thumb = create_img_thumbnail (bg, factory, screen, dest_width, dest_height, -1);
@@ -1677,14 +1680,13 @@ mate_bg_set_pixmap_as_root  (GdkScreen *screen, GdkPixmap *surface)
  * mate_bg_set_surface_as_root_with_crossfade:
  * @screen: the #GdkScreen to change root background on
  * @surface: the cairo xlib surface to set root background from
- * @context: a #GMainContext or %NULL
  *
  * Set the root pixmap, and properties pointing to it.
  * This function differs from mate_bg_set_surface_as_root()
  * in that it adds a subtle crossfade animation from the
  * current root pixmap to the new one.
  *
- * Return value: a #MateBGCrossfade object
+ * Return value: (transfer full): a #MateBGCrossfade object
  **/
 MateBGCrossfade *
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -2639,14 +2641,12 @@ pixbuf_draw_gradient (GdkPixbuf    *pixbuf,
 	int height;
 	int rowstride;
 	guchar *dst;
-	//guchar *dst_limit;
 	int n_channels = 3;
 
 	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
 	width = rect->width;
 	height = rect->height;
 	dst = gdk_pixbuf_get_pixels (pixbuf) + rect->x * n_channels + rowstride * rect->y;
-	//dst_limit = dst + height * rowstride;
 
 	if (horizontal) {
 		guchar *gradient = create_gradient (primary, secondary, width);
@@ -2821,6 +2821,8 @@ stack_is (SlideShow *parser,
 		s = va_arg (args, const char *);
 	}
 
+	va_end (args);
+
 	l1 = stack;
 	l2 = parser->stack->head;
 
@@ -2853,10 +2855,14 @@ handle_text (GMarkupParseContext *context,
 	     GError             **err)
 {
 	SlideShow *parser = user_data;
-	Slide *slide = parser->slides->tail? parser->slides->tail->data : NULL;
 	FileSize *fs;
 	gint i;
 
+	g_return_if_fail (parser != NULL);
+	g_return_if_fail (parser->slides != NULL);
+
+	Slide *slide = parser->slides->tail ? parser->slides->tail->data : NULL;
+
 	if (stack_is (parser, "year", "starttime", "background", NULL)) {
 		parser->start_tm.tm_year = parse_int (text) - 1900;
 	}
@@ -2877,11 +2883,15 @@ handle_text (GMarkupParseContext *context,
 	}
 	else if (stack_is (parser, "duration", "static", "background", NULL) ||
 		 stack_is (parser, "duration", "transition", "background", NULL)) {
+		g_return_if_fail (slide != NULL);
+
 		slide->duration = g_strtod (text, NULL);
 		parser->total_duration += slide->duration;
 	}
 	else if (stack_is (parser, "file", "static", "background", NULL) ||
 		 stack_is (parser, "from", "transition", "background", NULL)) {
+		g_return_if_fail (slide != NULL);
+
 		for (i = 0; text[i]; i++) {
 			if (!g_ascii_isspace (text[i]))
 				break;
@@ -2898,12 +2908,16 @@ handle_text (GMarkupParseContext *context,
 	}
 	else if (stack_is (parser, "size", "file", "static", "background", NULL) ||
 		 stack_is (parser, "size", "from", "transition", "background", NULL)) {
+		g_return_if_fail (slide != NULL);
+
 		fs = slide->file1->data;
 		fs->file = g_strdup (text);
 		if (slide->file1->next != NULL)
 			parser->has_multiple_sizes = TRUE;
 	}
 	else if (stack_is (parser, "to", "transition", "background", NULL)) {
+		g_return_if_fail (slide != NULL);
+
 		for (i = 0; text[i]; i++) {
 			if (!g_ascii_isspace (text[i]))
 				break;
@@ -2919,6 +2933,8 @@ handle_text (GMarkupParseContext *context,
 			parser->has_multiple_sizes = TRUE;
 	}
 	else if (stack_is (parser, "size", "to", "transition", "background", NULL)) {
+		g_return_if_fail (slide != NULL);
+
 		fs = slide->file2->data;
 		fs->file = g_strdup (text);
 		if (slide->file2->next != NULL)
@@ -3088,7 +3104,7 @@ read_slideshow_file (const char *filename,
 		/* one slide, there's no transition */
 		} else if (len == 1) {
 			Slide *slide = show->slides->head->data;
-			slide->duration = G_MAXUINT;
+			slide->duration = show->total_duration = G_MAXUINT;
 		}
 	}
 
@@ -3192,6 +3208,9 @@ mate_bg_changes_with_time (MateBG *bg)
 
 	g_return_val_if_fail (bg != NULL, FALSE);
 
+	if (!bg->filename)
+		return FALSE;
+
 	show = get_as_slideshow (bg, bg->filename);
 	if (show)
 		return g_queue_get_length (show->slides) > 1;
@@ -3199,9 +3218,15 @@ mate_bg_changes_with_time (MateBG *bg)
 	return FALSE;
 }
 
-/* Creates a thumbnail for a certain frame, where 'frame' is somewhat
+/**
+ * mate_bg_create_frame_thumbnail:
+ *
+ * Creates a thumbnail for a certain frame, where 'frame' is somewhat
  * vaguely defined as 'suitable point to show while single-stepping
- * through the slideshow'. Returns NULL if frame_num is out of bounds.
+ * through the slideshow'.
+ *
+ * Returns: (transfer full): the newly created thumbnail or
+ * or NULL if frame_num is out of bounds.
  */
 GdkPixbuf *
 mate_bg_create_frame_thumbnail (MateBG			*bg,
@@ -3250,7 +3275,7 @@ mate_bg_create_frame_thumbnail (MateBG			*bg,
 
 	result = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, dest_width, dest_height);
 
-	draw_color (bg, result, screen);
+	draw_color (bg, result);
 
 	if (bg->filename) {
 		thumb = create_img_thumbnail (bg, factory, screen,
